Imports System
Imports System.Data
Imports System.Drawing
Imports System.Configuration
Imports System.Web
Imports System.Web.Security
Imports System.Web.UI
Imports System.Web.UI.WebControls
Imports System.Web.UI.WebControls.WebParts
Imports System.Web.UI.HtmlControls

Imports MindFusion.Diagramming
Imports MindFusion.Diagramming.WebForms


Partial Public Class _Default
    Inherits System.Web.UI.Page

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load

        If Not IsPostBack Then

            _node = -1
            _column = -1
            _row = -1

            ' Load the initial diagram
            Dim diagram As Diagram = diagramView.Diagram
            Dim path As String = Server.MapPath("~") + "\\App_Data\\Diagram.xml"
            diagram.LoadFromXml(path)
        End If

    End Sub

    ' <summary>
    ' Page.OnLoadComplete override.
    ' </summary>
    Protected Overrides Sub OnLoadComplete(ByVal e As EventArgs)

        If (IsPostBack) Then

            ' Update the text of the currently selected object
            If _node <> -1 Then
                Dim node As DiagramNode = CType(diagramView.Diagram.Items(_node), DiagramNode)

                If (TypeOf node Is TableNode) Then
                    If _row = -1 Or _column = -1 Then
                        text.Text = CType(node, TableNode).Caption
                    Else
                        text.Text = CType(node, TableNode)(_column, _row).Text
                    End If
                End If

                If TypeOf node Is ShapeNode Then
                    text.Text = CType(node, ShapeNode).Text
                End If

            End If

        End If
    End Sub

    Dim a As Integer = 0

    Protected Sub diagramView_NodeClicked(ByVal sender As System.Object, ByVal e As MindFusion.Diagramming.NodeEventArgs) Handles diagramView.NodeClicked

        e.Node.Selected = True

        _node = e.Node.ZIndex
        _row = -1
        _column = -1

        If (TypeOf e.Node Is TableNode) Then _
            LogEvent("Table '" + CType(e.Node, TableNode).Caption + "' has been clicked.")
        If (TypeOf e.Node Is ShapeNode) Then _
            LogEvent("Shape '" + CType(e.Node, ShapeNode).Text + "' has been clicked.")
    End Sub

    Protected Sub diagramView_TableCellClicked(ByVal sender As System.Object, ByVal e As MindFusion.Diagramming.CellEventArgs) Handles diagramView.CellClicked

        e.Table.Selected = True

        _node = e.Table.ZIndex
        _row = e.Row
        _column = e.Column

        LogEvent("Cell (" & _column & ", " & _row & ") of table '" & _
            e.Table.Caption & "' has been clicked.")
    End Sub

    Protected Sub diagramView_TreeExpanded(ByVal sender As System.Object, ByVal e As MindFusion.Diagramming.NodeEventArgs) Handles diagramView.TreeExpanded
        If TypeOf e.Node Is TableNode Then
            LogEvent("Table '" & CType(e.Node, TableNode).Caption & _
                "' has been expanded.")
        End If

        If TypeOf e.Node Is ShapeNode Then
            LogEvent("Shape '" & CType(e.Node, ShapeNode).Text & _
                "' has been expanded.")
        End If
    End Sub

    Protected Sub diagramView_TreeCollapsed(ByVal sender As System.Object, ByVal e As MindFusion.Diagramming.NodeEventArgs) Handles diagramView.TreeCollapsed
        If TypeOf e.Node Is TableNode Then
            LogEvent("Table '" & CType(e.Node, TableNode).Caption & _
                "' has been collapsed.")
        End If

        If TypeOf e.Node Is ShapeNode Then
            LogEvent("Shape '" & CType(e.Node, ShapeNode).Text & _
                "' has been collapsed.")
        End If
    End Sub

    Protected Sub button_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles button.Click

        ' Change the text of the selected item
        If _node <> -1 Then

            Dim node As DiagramNode = CType(diagramView.Diagram.Items(_node), DiagramNode)

            If TypeOf node Is TableNode Then
                If (_row = -1 Or _column = -1) Then
                    CType(node, TableNode).Caption = text.Text
                Else
                    CType(node, TableNode)(_column, _row).Text = text.Text
                End If
            End If

            If TypeOf node Is ShapeNode Then
                CType(node, ShapeNode).Text = text.Text
            End If
        End If
    End Sub

    Protected Sub button1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles button1.Click
		' Change the text of the selected item
        Select Case (imageFormat.SelectedIndex)
			Case 0
				diagramView.ImageFormat = "image/jpeg"
            Case 1
                diagramView.ImageFormat = "image/bmp"
            Case 2
                diagramView.ImageFormat = "image/gif"
            Case 3
                diagramView.ImageFormat = "image/png"
        End Select
    End Sub

    ' <summary>
    ' Appends the specified event to the event log.
    ' </summary>
    Private Sub LogEvent(ByVal eventMessage As String)

        Dim builder As System.Text.StringBuilder = New System.Text.StringBuilder()

        builder.Append(eventlog.Text)
        builder.Append(String.Format("<b><font color='#999999'>[{0}]</font></b> ", DateTime.Now.ToString("HH:mm:ss")))
        builder.Append(eventMessage)
        builder.Append("<br>")

        eventlog.Text = builder.ToString()
    End Sub

    Protected Overrides Function SaveViewState() As Object

        Dim map As System.Collections.Hashtable = New System.Collections.Hashtable()

        map.Add("Node", _node)
        map.Add("Column", _column)
        map.Add("Row", _row)
        map.Add("ImageFormat", diagramView.ImageFormat)

        Return map
    End Function

    Protected Overrides Sub LoadViewState(ByVal savedState As Object)

        Dim map As System.Collections.Hashtable = CType(savedState, System.Collections.Hashtable)

        If map Is Nothing Then
            Return
        End If

        _node = CType(map("Node"), Integer)
        _column = CType(map("Column"), Integer)
        _row = CType(map("Row"), Integer)

        Dim imageFormat As String = CType(map("ImageFormat"), String)
        diagramView.ImageFormat = imageFormat

        ' Update the format choice
        Select Case (imageFormat)
		
            Case "image/jpeg"
                Me.imageFormat.SelectedIndex = 0
		
            Case "image/bmp"
                Me.imageFormat.SelectedIndex = 1
		
            Case "image/gif"
                Me.imageFormat.SelectedIndex = 2
		
            Case "image/png"
                Me.imageFormat.SelectedIndex = 3
		
        End Select
    End Sub

    ' <summary>
    ' The x-index of the selected node.
    ' </summary>
    Dim _node As Integer

    ' <summary>
    ' The column of the selected cell.
    ' </summary>
    Dim _column As Integer

    ' <summary>
    ' The row of the selected cell.
    ' </summary>
    Dim _row As Integer

End Class